==================================================================
demuxEM for demultiplexing cell/nucleus hashing single-cell data
==================================================================

|PyPI|

.. |PyPI| image:: https://img.shields.io/pypi/v/demuxEM.svg
   :target: https://pypi.org/project/demuxEM


demuxEM is the demultiplexing module of Pegasus.

`Read documentation <http://pegasus.readthedocs.io>`__
